@@ -1,7 +1,6 @@
 package Perl::Lint::Policy::RegularExpressions::ProhibitComplexRegexes;
 use strict;
 use warnings;
-use Perl::Lint::RegexpParser;
 use Perl::Lint::Constants::Type;
 use parent "Perl::Lint::Policy";
 
@@ -15,8 +14,6 @@ sub evaluate {
 
     my $max_characters = $args->{prohibit_complex_regexes}->{max_characters} || 60;
 
-    my $regexp_parser = Perl::Lint::RegexpParser->new; # to use to check the regexp syntax
-
     my @violations;
     my $is_reg_quote = 0;
     my $is_delimiter_single_quote = 0;
@@ -43,11 +40,6 @@ sub evaluate {
                 next;
             }
 
-            if (!$regexp_parser->parse($regexp)) {
-                # invalid regexp with syntax error
-                next;
-            }
-
             if (!$_is_delimiter_single_quote) {
                 # replace variables
                 while ($regexp =~ /(\\*)([\$\@]\S+)/gc) {
@@ -64,6 +56,7 @@ sub evaluate {
 
             my $maybe_regopt = $tokens->[$i+2]; # XXX right!?
             if (
+                $maybe_regopt &&
                 $maybe_regopt->{type} == REG_OPT &&
                 $maybe_regopt->{data} =~ /x/
             ) {
