@@ -120,14 +120,18 @@ sub evaluate {
             }
         }
 
-        if ($token_type == INT && $token_data != 0 && $token_data =~ /\A-?0/) {
-            push @violations, {
-                filename => $file,
-                line     => $token->{line},
-                description => DESC,
-                explanation => EXPL,
-                policy => __PACKAGE__,
-            };
+        if ($token_type == INT) {
+            my $int = $token_data;
+            $int =~ s/_//g;
+            if ($int != 0 && $int =~ /\A-?0/) {
+                push @violations, {
+                    filename => $file,
+                    line     => $token->{line},
+                    description => DESC,
+                    explanation => EXPL,
+                    policy => __PACKAGE__,
+                };
+            }
             next;
         }
     }
